﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace EjemploCSharp
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void btnRegistroEmisor_Click(object sender, EventArgs e)
        {
            //Hacer referencia al servicio web de pruebas de timbrado, que se encuentra en la siguiente URL
            //'http://201.175.12.89/ServicioIntegracionPruebas/Timbrado.asmx

            //En este ejemplo la referencia al servicio web de timbrado será identificada como 'ServicioIntegracionReference'
            //
            //El servicio para registro de emisores funciona de la siguiente manera
            //
            //Se reciben 5 parámetros
            //
            //Usuario Integrador (Especificar el usuario integrador asignado, para efecto de pruebas se utilizará el usuario 'mvpNUXmQfK8=')
            //Rfc Emisor (El rfc del emisor a registrar, para efecto de pruebas se utilizará el RFC genérico 'AAA010101AAA')
            //Archivo .cer del sello digital en base64 (El archivo .cer es necesario para el sellado del comprobante en caso de ser requerido y cancelaciones, para efecto de 
            //pruebas se utilizará el certificado proporcionado con el Kit de desarrollo)
            //Archivo .key del sello digital en base64 (El archivo .key es necesario para el sellado del comprobante en caso de ser requerido y cancelaciones, para efecto de)
            //pruebas se utilizará el certificado proporcionado con el Kit de desarrollo)
            //Contraseña del sello digital (La contraseña es requerida para la lectura del sello, para efecto de pruebas se utilizará la contraseña '12345678a')

            //Parametros
            string usuarioIntegrador = "mvpNUXmQfK8=";
            string rfcEmisor = "AAA010101AAA";
            string archivoCerBase64 = Convert.ToBase64String(System.IO.File.ReadAllBytes(@"C:\aaa010101aaa__csd_01.cer"));
            string archivoKeyBase64 = Convert.ToBase64String(System.IO.File.ReadAllBytes(@"C:\aaa010101aaa__csd_01.key"));
            string contrasena = "12345678a";

            //Llamamos al web method Registra Emisor
            ServicioIntegracionReference.TimbradoSoapClient soapClient = new ServicioIntegracionReference.TimbradoSoapClient();
            ServicioIntegracionReference.ArrayOfAnyType resultados = soapClient.RegistraEmisor(usuarioIntegrador, rfcEmisor, archivoCerBase64, archivoKeyBase64, contrasena);

            //Obtenemos datos del registro

            //Tipo de excepcion
            string tipoExcepcion = resultados[0].ToString();
            //Numero de error
            string numeroError = resultados[1].ToString();
            //Descripcion del resultado
            string descripcion = resultados[2].ToString();
            //Xml no aplica en registro emisor
            string xml = resultados[3].ToString();
            //Codigo bidimensional no aplica en registro emisor
            Bitmap codigoBidimensional = resultados[4] as Bitmap;
            //Cadena timbre no aplica en registro emisor
            string cadenaTimbre = resultados[5].ToString();

            //Vefificamos que el resultado haya sido exitoso
            if (numeroError == "0")
            {
                MessageBox.Show("El emisor fue registrado correctamente");
            }
            else
            {
                //Ocurrió un error en el registro del emisor
                MessageBox.Show(descripcion);
            }
        }

        private void btnTimbrado_Click(object sender, EventArgs e)
        {
            //Hacer referencia al servicio web de pruebas de timbrado, que se encuentra en la siguiente URL
            //'http://201.175.12.89/ServicioIntegracionPruebas/Timbrado.asmx

            //En este ejemplo la referencia al servicio web de timbrado será identificada como 'ServicioIntegracionReference'
            //
            //El servicio para timbrado funciona de la siguiente manera
            //
            //Se reciben 3 parámetros
            //
            //Usuario Integrador (Especificar el usuario integrador asignado, para efecto de pruebas se utilizará el usuario 'mvpNUXmQfK8=')
            //Xml (El archivo xml a timbrar en base64)
            //IdComprobante (Un identificador único para el timbrado de cada comprobante)

            //Parametros
            string usuarioIntegrador = "mvpNUXmQfK8=";
            string comprobanteBase64 = Convert.ToBase64String(System.IO.File.ReadAllBytes(@"C:\comprobanteSinTimbrar.xml"));
            //Para efecto de pruebas se utilizará un número aleatorio
            Random miRandom = new Random();
            string idComprobante = miRandom.Next(0, 999999).ToString();

            //Llamamos al web method Registra Emisor
            ServicioIntegracionReference.TimbradoSoapClient soapClient = new ServicioIntegracionReference.TimbradoSoapClient();
            ServicioIntegracionReference.ArrayOfAnyType resultados = soapClient.TimbraCFDI(usuarioIntegrador, comprobanteBase64, idComprobante);

            //Obtenemos datos del registro

            //Tipo de excepcion
            string tipoExcepcion = resultados[0].ToString();
            //Numero de error
            string numeroError = resultados[1].ToString();
            //Descripcion del resultado
            string descripcion = resultados[2].ToString();
            //Xml timbrado
            string xml = resultados[3].ToString();
            //Codigo bidimensional
            byte[] codigoBidimensional = (byte[])(resultados[4]);
            //Cadena timbre
            string cadenaTimbre = resultados[5].ToString();

            //Vefificamos que el resultado haya sido exitoso
            if (numeroError == "0")
            {
                MessageBox.Show("El comprobante fue timbrado exitosamente");
            }
            else
            {
                //Ocurrió un error en el timbrado
                MessageBox.Show(descripcion);
            }
        }

        private void btnObtenerCfdi_Click(object sender, EventArgs e)
        {
            //Hacer referencia al servicio web de pruebas de timbrado, que se encuentra en la siguiente URL
            //'http://201.175.12.89/ServicioIntegracionPruebas/Timbrado.asmx

            //En este ejemplo la referencia al servicio web de timbrado será identificada como 'ServicioIntegracionReference'
            //
            //El servicio para obtener un cfdi previamente timbrado funciona de la siguiente manera
            //
            //Se reciben 3 parámetros
            //
            //Usuario Integrador (Especificar el usuario integrador asignado, para efecto de pruebas se utilizará el usuario 'mvpNUXmQfK8=')
            //RfcEmisor (El Rfc del emisor del cual queremos obtener el CFDI)
            //Folio Fiscal (El folio fiscal del comprobante que queremos obtener)

            //Parametros
            string usuarioIntegrador = "mvpNUXmQfK8=";
            string rfcEmisor = "AAA010101AAA";
            string folioFiscal = txtFolioFiscal.Text.Trim().ToUpper();

            //Llamamos al web method ObtieneCFDI
            ServicioIntegracionReference.TimbradoSoapClient soapClient = new ServicioIntegracionReference.TimbradoSoapClient();
            ServicioIntegracionReference.ArrayOfAnyType resultados = soapClient.ObtieneCFDI(usuarioIntegrador, rfcEmisor, folioFiscal);

            //Obtenemos datos del registro

            //Tipo de excepcion
            string tipoExcepcion = resultados[0].ToString();
            //Numero de error
            string numeroError = resultados[1].ToString();
            //Descripcion del resultado
            string descripcion = resultados[2].ToString();
            //Xml 
            string xml = resultados[3].ToString();
            //Codigo bidimensional no aplica en obtiene cfdi
            byte[] codigoBidimensional = (byte[])(resultados[4]);
            //Cadena timbre no aplica en obtiene cfdi
            string cadenaTimbre = resultados[5].ToString();

            //Vefificamos que el resultado haya sido exitoso
            if (numeroError == "0")
            {
                MessageBox.Show("El comprobante fue consultado exitosamente");
            }
            else
            {
                //Ocurrió un error en la obtención del CFDI
                MessageBox.Show(descripcion);
            }
        }

        private void btnCancelacion_Click(object sender, EventArgs e)
        {
            //Hacer referencia al servicio web de pruebas de timbrado, que se encuentra en la siguiente URL
            //'http://201.175.12.89/ServicioIntegracionPruebas/Timbrado.asmx

            //En este ejemplo la referencia al servicio web de timbrado será identificada como 'ServicioIntegracionReference'
            //
            //El servicio para cancelar un cfdi funciona de la siguiente manera
            //
            //Se reciben 3 parámetros
            //
            //Usuario Integrador (Especificar el usuario integrador asignado, para efecto de pruebas se utilizará el usuario 'mvpNUXmQfK8=')
            //RfcEmisor (El Rfc del emisor del cual queremos cancelar el CFDI)
            //Folio Fiscal (El folio fiscal del comprobante que queremos cancelar)

            //Parametros
            string usuarioIntegrador = "mvpNUXmQfK8=";
            string rfcEmisor = "AAA010101AAA";
            string folioFiscal = txtFolioFiscalCancelacion.Text.Trim().ToUpper();

            //Llamamos al web method ObtieneCFDI
            ServicioIntegracionReference.TimbradoSoapClient soapClient = new ServicioIntegracionReference.TimbradoSoapClient();
            ServicioIntegracionReference.ArrayOfAnyType resultados = soapClient.CancelaCFDI(usuarioIntegrador, rfcEmisor, folioFiscal);

            //Obtenemos datos del registro

            //Tipo de excepcion
            string tipoExcepcion = resultados[0].ToString();
            //Numero de error
            string numeroError = resultados[1].ToString();
            //Descripcion del resultado
            string descripcion = resultados[2].ToString();
            //Xml 
            string xml = resultados[3].ToString();
            //Codigo bidimensional no aplica en obtiene cfdi
            byte[] codigoBidimensional = (byte[])(resultados[4]);
            //Cadena timbre no aplica en obtiene cfdi
            string cadenaTimbre = resultados[5].ToString();

            //Vefificamos que el resultado haya sido exitoso
            if (numeroError == "0")
            {
                MessageBox.Show("El comprobante fue cancelado exitosamente");
            }
            else
            {
                //Ocurrió un error en la cancelación del CFDI
                MessageBox.Show(descripcion);
            }
        }
    }
}
